program errequal_dsp
   * Michael Tomz and Robert Van Houweling, "Candidate Positioning and Voter Choice,"
   * American Political Science Review 102, no. 3 (August 2008): 303-318.
   *
   * Purpose: Part of Appendix B
   *    estimate rates of prox, disc, dir, error, assuming that error rate is
   *    function of dcbar, dpbar, and absolute difference in scalar products (dsp)
   * Version: February 21, 2010
   * Syntax:  Stata 9.2   
   version 9.2
   args lnf et pdirt pdisct ff
   tempname pdir pdisc e denom 
   scalar `denom' = 1+exp(`pdirt')+exp(`pdisct')
   scalar `pdir' = exp(`pdirt')/`denom'
   scalar `pdisc' = exp(`pdisct')/`denom'
   scalar `e' = 1/(1+exp(-`et'))
   quietly {
	  replace `lnf' = ln((1 - `pdisc' - `pdir')*(.5 * exp(`ff'*$dcbar) + `e') + `pdisc'*(.5 * exp(`ff'*$dpbar) + `e') + `pdir'*(1 - .5 * exp(`ff'*$dsp) - `e')) if $ML_y1==1  & $S==1
	  replace `lnf' = ln(1-((1 - `pdisc' - `pdir')*(.5 * exp(`ff'*$dcbar) + `e') + `pdisc'*(.5 * exp(`ff'*$dpbar) + `e') + `pdir'*(1 - .5 * exp(`ff'*$dsp) - `e'))) if $ML_y1==0  & $S==1
	  replace `lnf' = ln((1 - `pdisc' - `pdir')*(.5 * exp(`ff'*$dcbar) + `e') + `pdisc'*(.5 * exp(`ff'*$dpbar) + `e') + `pdir'*(.5 * exp(`ff'*$dsp) + `e')) if $ML_y1==1 & $S==2
	  replace `lnf' = ln(1-((1 - `pdisc' - `pdir')*(.5 * exp(`ff'*$dcbar) + `e') + `pdisc'*(.5 * exp(`ff'*$dpbar) + `e') + `pdir'*(.5 * exp(`ff'*$dsp) + `e'))) if $ML_y1==0  & $S==2
	  replace `lnf' = ln((1 - `pdisc' - `pdir')*(.5 * exp(`ff'*$dcbar) + `e') + `pdisc'*(1 - .5 * exp(`ff'*$dpbar) - `e') + `pdir'*(1 - .5 * exp(`ff'*$dsp) - `e')) if $ML_y1==1 & $S==4
	  replace `lnf' = ln(1-((1 - `pdisc' - `pdir')*(.5 * exp(`ff'*$dcbar) + `e') + `pdisc'*(1 - .5 * exp(`ff'*$dpbar) - `e') + `pdir'*(1 - .5 * exp(`ff'*$dsp) - `e'))) if $ML_y1==0 & $S==4
   }
end
