* Michael Tomz and Robert Van Houweling, "Candidate Positioning and Voter Choice,"
* American Political Science Review 102, no. 3 (August 2008): 303-318.
*
* Purpose: Prepare data for analysis
* Version: February 21, 2010
* Syntax:  Stata 9.2
version 9.2
set more off
********************************
* LOAD DATA FROM DECEMBER 2005 *
********************************
use 2005_12.dta, clear
gen self = q1
recode self 1=-5 2=-4 3=-3 4=-2 5=-1 6=0 7=1 8=2 9=3 10=4 11=5 *=. /* position of respondent */
recode a 1=-5 2=-4 3=-3 4=-2 5=-1 6=0 7=1 8=2 9=3 10=4 11=5 *=.    /* position of candidate A */
recode b 1=-5 2=-4 3=-3 4=-2 5=-1 6=0 7=1 8=2 9=3 10=4 11=5 *=.    /* position of candidate B */
gen candleft = min(a, b)                                           /* position of leftmost candidate */
gen candright = max(a, b)                                          /* position of rightmost candidate */
gen byte pickleft = cond( (q2==1 & candleft==a) | (q2==2 & candleft==b),1,0) if q2~=. & candleft~=.
gen sq = q3
recode sq 1=-5 2=-4 3=-3 4=-2 5=-1 6=0 7=1 8=2 9=3 10=4 11=5
gen pid7 = party7
recode pid7 1=7 2=6 3=5 4=4 5=3 6=2 7=1 *=.
gen ideo7 = ideo
recode ideo7 9=.
rename ppeducat ed4
drop q1 q2 q3 a b party7 party3 ideo agegroup workold xq212 xq22 xq28
tempfile 2005_12
save `2005_12', replace

********************************
* LOAD DATA FROM MAY/JUNE 2006 *
********************************
use 2006_06.dta, clear
gen self = q1
recode self 1=-5 2=-4 3=-3 4=-2 5=-1 6=0 7=1 8=2 9=3 10=4 11=5 *=. /* position of respondent */
gen candleft = .   /* position of leftmost candidate */
gen candright = .  /* position of rightmost candidate */
#delimit ;
replace candleft = -4 if value == 1; replace candright = -1 if value == 1;
replace candleft = -4 if value == 2; replace candright = 0 if value == 2;
replace candleft = -4 if value == 3; replace candright = 1 if value == 3;
replace candleft = -4 if value == 4; replace candright = 2 if value == 4;
replace candleft = -4 if value == 5; replace candright = 3 if value == 5;
replace candleft = -4 if value == 6; replace candright = 4 if value == 6;
replace candleft = -3 if value == 7; replace candright = -2 if value == 7;
replace candleft = -3 if value == 8; replace candright = -1 if value == 8;
replace candleft = -3 if value == 9; replace candright = 0 if value == 9;
replace candleft = -3 if value == 10; replace candright = 1 if value == 10;
replace candleft = -3 if value == 11; replace candright = 2 if value == 11;
replace candleft = -3 if value == 12; replace candright = 3 if value == 12;
replace candleft = -3 if value == 13; replace candright = 4 if value == 13;
replace candleft = -2 if value == 14; replace candright = -1 if value == 14;
replace candleft = -2 if value == 15; replace candright = 0 if value == 15;
replace candleft = -2 if value == 16; replace candright = 1 if value == 16;
replace candleft = -2 if value == 17; replace candright = 2 if value == 17;
replace candleft = -2 if value == 18; replace candright = 3 if value == 18;
replace candleft = -2 if value == 19; replace candright = 4 if value == 19;
replace candleft = -1 if value == 20; replace candright = 0 if value == 20;
replace candleft = -1 if value == 21; replace candright = 1 if value == 21;
replace candleft = -1 if value == 22; replace candright = 2 if value == 22;
replace candleft = -1 if value == 23; replace candright = 3 if value == 23;
replace candleft = -1 if value == 24; replace candright = 4 if value == 24;
replace candleft = 0 if value == 25; replace candright = 1 if value == 25;
replace candleft = 0 if value == 26; replace candright = 2 if value == 26;
replace candleft = 0 if value == 27; replace candright = 3 if value == 27;
replace candleft = 0 if value == 28; replace candright = 4 if value == 28;
replace candleft = 1 if value == 29; replace candright = 2 if value == 29;
replace candleft = 1 if value == 30; replace candright = 3 if value == 30;
replace candleft = 1 if value == 31; replace candright = 4 if value == 31;
replace candleft = 2 if value == 32; replace candright = 3 if value == 32;
replace candleft = 2 if value == 33; replace candright = 4 if value == 33;
replace candleft = 3 if value == 34; replace candright = 4 if value == 34;
replace candleft = -4 if value == 35; replace candright = 1 if value == 35;
replace candleft = -4 if value == 36; replace candright = 2 if value == 36;
replace candleft = -4 if value == 37; replace candright = 3 if value == 37;
replace candleft = -4 if value == 38; replace candright = 4 if value == 38;
replace candleft = -3 if value == 39; replace candright = 0 if value == 39;
replace candleft = -3 if value == 40; replace candright = 1 if value == 40;
replace candleft = -3 if value == 41; replace candright = 2 if value == 41;
replace candleft = -3 if value == 42; replace candright = 3 if value == 42;
replace candleft = -3 if value == 43; replace candright = 4 if value == 43;
replace candleft = -2 if value == 44; replace candright = -1 if value == 44;
replace candleft = -2 if value == 45; replace candright = 0 if value == 45;
replace candleft = -2 if value == 46; replace candright = 1 if value == 46;
replace candleft = -2 if value == 47; replace candright = 2 if value == 47;
replace candleft = -2 if value == 48; replace candright = 3 if value == 48;
replace candleft = -2 if value == 49; replace candright = 4 if value == 49;
replace candleft = -1 if value == 50; replace candright = 0 if value == 50;
replace candleft = -1 if value == 51; replace candright = 1 if value == 51;
replace candleft = -1 if value == 52; replace candright = 2 if value == 52;
replace candleft = -1 if value == 53; replace candright = 3 if value == 53;
replace candleft = -1 if value == 54; replace candright = 4 if value == 54;
replace candleft = 0 if value == 55; replace candright = 1 if value == 55;
replace candleft = 0 if value == 56; replace candright = 2 if value == 56;
replace candleft = 0 if value == 57; replace candright = 3 if value == 57;
replace candleft = 0 if value == 58; replace candright = 4 if value == 58;
replace candleft = 1 if value == 59; replace candright = 2 if value == 59;
replace candleft = 1 if value == 60; replace candright = 3 if value == 60;
replace candleft = 1 if value == 61; replace candright = 4 if value == 61;
replace candleft = 2 if value == 62; replace candright = 3 if value == 62;
replace candleft = 2 if value == 63; replace candright = 4 if value == 63;
replace candleft = 3 if value == 64; replace candright = 4 if value == 64;
replace candleft = -4 if value == 65; replace candright = 3 if value == 65;
replace candleft = -4 if value == 66; replace candright = 4 if value == 66;
replace candleft = -3 if value == 67; replace candright = 2 if value == 67;
replace candleft = -3 if value == 68; replace candright = 3 if value == 68;
replace candleft = -3 if value == 69; replace candright = 4 if value == 69;
replace candleft = -2 if value == 70; replace candright = 1 if value == 70;
replace candleft = -2 if value == 71; replace candright = 2 if value == 71;
replace candleft = -2 if value == 72; replace candright = 3 if value == 72;
replace candleft = -2 if value == 73; replace candright = 4 if value == 73;
replace candleft = -1 if value == 74; replace candright = 0 if value == 74;
replace candleft = -1 if value == 75; replace candright = 1 if value == 75;
replace candleft = -1 if value == 76; replace candright = 2 if value == 76;
replace candleft = -1 if value == 77; replace candright = 3 if value == 77;
replace candleft = -1 if value == 78; replace candright = 4 if value == 78;
replace candleft = 0 if value == 79; replace candright = 1 if value == 79;
replace candleft = 0 if value == 80; replace candright = 2 if value == 80;
replace candleft = 0 if value == 81; replace candright = 3 if value == 81;
replace candleft = 0 if value == 82; replace candright = 4 if value == 82;
replace candleft = 1 if value == 83; replace candright = 2 if value == 83;
replace candleft = 1 if value == 84; replace candright = 3 if value == 84;
replace candleft = 1 if value == 85; replace candright = 4 if value == 85;
replace candleft = 2 if value == 86; replace candright = 3 if value == 86;
replace candleft = 2 if value == 87; replace candright = 4 if value == 87;
replace candleft = 3 if value == 88; replace candright = 4 if value == 88;
replace candleft = -4 if value == 97; replace candright = -3 if value == 97;
replace candleft = -4 if value == 98; replace candright = -2 if value == 98;
replace candleft = -4 if value == 99; replace candright = -1 if value == 99;
replace candleft = -4 if value == 100; replace candright = 0 if value == 100;
replace candleft = -4 if value == 101; replace candright = 1 if value == 101;
replace candleft = -4 if value == 102; replace candright = 2 if value == 102;
replace candleft = -4 if value == 103; replace candright = 3 if value == 103;
replace candleft = -4 if value == 104; replace candright = 4 if value == 104;
replace candleft = -3 if value == 105; replace candright = -2 if value == 105;
replace candleft = -3 if value == 106; replace candright = -1 if value == 106;
replace candleft = -3 if value == 107; replace candright = 0 if value == 107;
replace candleft = -3 if value == 108; replace candright = 1 if value == 108;
replace candleft = -3 if value == 109; replace candright = 2 if value == 109;
replace candleft = -3 if value == 110; replace candright = 3 if value == 110;
replace candleft = -3 if value == 111; replace candright = 4 if value == 111;
replace candleft = -2 if value == 112; replace candright = -1 if value == 112;
replace candleft = -2 if value == 113; replace candright = 0 if value == 113;
replace candleft = -2 if value == 114; replace candright = 1 if value == 114;
replace candleft = -2 if value == 115; replace candright = 2 if value == 115;
replace candleft = -2 if value == 116; replace candright = 3 if value == 116;
replace candleft = -1 if value == 117; replace candright = 0 if value == 117;
replace candleft = -1 if value == 118; replace candright = 1 if value == 118;
replace candleft = -1 if value == 119; replace candright = 2 if value == 119;
replace candleft = 0 if value == 120; replace candright = 1 if value == 120;
replace candleft = -4 if value == 121; replace candright = -3 if value == 121;
replace candleft = -4 if value == 122; replace candright = -2 if value == 122;
replace candleft = -4 if value == 123; replace candright = -1 if value == 123;
replace candleft = -4 if value == 124; replace candright = 0 if value == 124;
replace candleft = -4 if value == 125; replace candright = 1 if value == 125;
replace candleft = -4 if value == 126; replace candright = 2 if value == 126;
replace candleft = -4 if value == 127; replace candright = 3 if value == 127;
replace candleft = -4 if value == 128; replace candright = 4 if value == 128;
replace candleft = -3 if value == 129; replace candright = -2 if value == 129;
replace candleft = -3 if value == 130; replace candright = -1 if value == 130;
replace candleft = -3 if value == 131; replace candright = 0 if value == 131;
replace candleft = -3 if value == 132; replace candright = 1 if value == 132;
replace candleft = -3 if value == 133; replace candright = 2 if value == 133;
replace candleft = -3 if value == 134; replace candright = 3 if value == 134;
replace candleft = -3 if value == 135; replace candright = 4 if value == 135;
replace candleft = -2 if value == 136; replace candright = -1 if value == 136;
replace candleft = -2 if value == 137; replace candright = 0 if value == 137;
replace candleft = -2 if value == 138; replace candright = 1 if value == 138;
replace candleft = -2 if value == 139; replace candright = 2 if value == 139;
replace candleft = -2 if value == 140; replace candright = 3 if value == 140;
replace candleft = -2 if value == 141; replace candright = 4 if value == 141;
replace candleft = -1 if value == 142; replace candright = 0 if value == 142;
replace candleft = -1 if value == 143; replace candright = 1 if value == 143;
replace candleft = -1 if value == 144; replace candright = 2 if value == 144;
replace candleft = -1 if value == 145; replace candright = 3 if value == 145;
replace candleft = -1 if value == 146; replace candright = 4 if value == 146;
replace candleft = 0 if value == 147; replace candright = 1 if value == 147;
replace candleft = 0 if value == 148; replace candright = 2 if value == 148;
replace candleft = 0 if value == 149; replace candright = 3 if value == 149;
replace candleft = 1 if value == 150; replace candright = 2 if value == 150;
replace candleft = -4 if value == 151; replace candright = -3 if value == 151;
replace candleft = -4 if value == 152; replace candright = -2 if value == 152;
replace candleft = -4 if value == 153; replace candright = -1 if value == 153;
replace candleft = -4 if value == 154; replace candright = 0 if value == 154;
replace candleft = -4 if value == 155; replace candright = 1 if value == 155;
replace candleft = -4 if value == 156; replace candright = 2 if value == 156;
replace candleft = -4 if value == 157; replace candright = 3 if value == 157;
replace candleft = -4 if value == 158; replace candright = 4 if value == 158;
replace candleft = -3 if value == 159; replace candright = -2 if value == 159;
replace candleft = -3 if value == 160; replace candright = -1 if value == 160;
replace candleft = -3 if value == 161; replace candright = 0 if value == 161;
replace candleft = -3 if value == 162; replace candright = 1 if value == 162;
replace candleft = -3 if value == 163; replace candright = 2 if value == 163;
replace candleft = -3 if value == 164; replace candright = 3 if value == 164;
replace candleft = -3 if value == 165; replace candright = 4 if value == 165;
replace candleft = -2 if value == 166; replace candright = -1 if value == 166;
replace candleft = -2 if value == 167; replace candright = 0 if value == 167;
replace candleft = -2 if value == 168; replace candright = 1 if value == 168;
replace candleft = -2 if value == 169; replace candright = 2 if value == 169;
replace candleft = -2 if value == 170; replace candright = 3 if value == 170;
replace candleft = -2 if value == 171; replace candright = 4 if value == 171;
replace candleft = -1 if value == 172; replace candright = 0 if value == 172;
replace candleft = -1 if value == 173; replace candright = 1 if value == 173;
replace candleft = -1 if value == 174; replace candright = 2 if value == 174;
replace candleft = -1 if value == 175; replace candright = 3 if value == 175;
replace candleft = -1 if value == 176; replace candright = 4 if value == 176;
replace candleft = 0 if value == 177; replace candright = 1 if value == 177;
replace candleft = 0 if value == 178; replace candright = 2 if value == 178;
replace candleft = 0 if value == 179; replace candright = 3 if value == 179;
replace candleft = 0 if value == 180; replace candright = 4 if value == 180;
replace candleft = 1 if value == 181; replace candright = 2 if value == 181;
replace candleft = 1 if value == 182; replace candright = 3 if value == 182;
replace candleft = 1 if value == 183; replace candright = 4 if value == 183;
replace candleft = 2 if value == 184; replace candright = 3 if value == 184;
replace candleft = . if qflag ~= 1;
replace candright = . if qflag ~= 1;
#delimit cr
* note: if ab=1, then a is leftmost candidate; if ab=2, then b is leftmost candidate
gen byte pickleft = cond((ab==1 & q2==1)|(ab==2 & q2==2),1,0) if candleft~=. & self~=0  /* chose the leftmost candidate */
gen sq = q3 if self~=0
recode sq 1=-5 2=-4 3=-3 4=-2 5=-1 6=0 7=1 8=2 9=3 10=4 11=5 *=.
replace qflag = 2 if self==0
gen pid7 = partyid7
recode pid7 1=7 2=6 3=5 4=4 5=3 6=2 7=1 *=.
gen ideo7 = ideo
recode ideo7 9=.
rename ppeducat ed4
drop q1 q2 q3 value ab agegroup partyid7 partyid3


*****************************
* STACK, LABEL THE DATASETS *
*****************************
append using `2005_12'
label var self "Respondent's policy preference"
label var candleft "Position of candidate on left"
label var candright "Position of candidate on right"
label var sq "Position of the status quo"
label var pickleft "R chose candidate on left"
label var ed4 "Education: 4 categories"
label var pid7 "Party ID: 7pt (dem=1)"
label define pid7 1 "Str Dem" 2 "Weak Dem" 3 "Lean Dem" 4 "Indep" 5 "Lean Rep" 6 "Weak Rep" 7 "Str Rep"
label values pid7 pid7
label var ideo7 "Ideology: 7pt (lib=1)"
label define ideo7 1 "Extremely L" 2 "Liberal" 3 "Slightly L" 4 "Moderate" 5 "Slightly C" 6 "Conservative" 7 "Extremely C"
label values ideo7 ideo7
format dt_start %8.0f
order dt_start qflag self candleft candright sq pickleft pid7 ideo7 ed4 ppgender

******************************
* MAKE DEMOGRAPHIC VARIABLES *
******************************
gen agecat = ppage
recode agecat 18/24=1 25/34=2 35/44=3 45/54=4 55/64=5 65/150=6 *=.
label define agecat 1 "18-24" 2 "25-34" 3 "35-44" 4 "45-54" 5 "55-64" 6 "65+"
label values agecat agecat
label var agecat "Age: 6 categories"
gen married = ppmarit
gen inc = ppincimp
recode inc 1/3=1 4/7=2 8/11=3 12/13=4 14/19=5 *=.
label define inc 1 "< 10k" 2 "10 - 24.9" 3 "25 - 49.9" 4 "50 - 74.9" 5 "75+"
label values inc inc
label var inc "Household income: 5 categories"
recode married 1=1 2/5=0 *=.
label var married "R is married"
gen white = ppethm
recode white 1=1 4=1 2/3=0 5=0 *=.
label var white "R is white"

*********************************
* Pre-Screened Sample (N=3,315) *
*********************************
describe                          
tab self
tab ppgender
tab agecat
tab ed4
tab inc
tab married
tab white
tab ppreg4
tab pid7
tab ideo7

*************************
* Completion Rate ~ 72% *
*************************
* Invitations were sent to 2,778 in December 2005 and to 1,801 in May/June 2006
di 3315/(2778+1801)  // completion rate

**************************
* Screen-out Respondents *
**************************
tab self qflag                    /* Did not continue with R's at -5, 0, +5 */
tab qflag if self==-4 | self==4   /* Did not continue with 40% of R's at -4,+4 (see footnote 15) */
tab self if qflag == 1            /* After dropping nonqualifiers, N = 1,577 (see footnote 15) */
drop if qflag==1 & (pickleft == . | sq == .)   /* didn't pick a candididate or locate sq (see fn15) */

*****************************
* Screened Sample (N=1,564) *
*****************************
tab self if qflag == 1            
tab ppgender if qflag == 1
tab agecat if qflag == 1
tab ed4 if qflag == 1
tab inc if qflag == 1
tab married if qflag == 1
tab white if qflag == 1
tab ppreg4 if qflag == 1
tab pid7 if qflag == 1
tab ideo7 if qflag == 1

*********************************
* SAVE THE DATASET FOR ANALYSIS *
*********************************
compress
save TomzVanHouweling_APSR_2008, replace
